0.2.2 (10-20-2020)
==================

Bugs
----
* Fixed an ``quesadiya run`` issue by making subprocess executable.
* Fixed a type in ``setup.py`` so it downloads django package when being
  donwloaded by pip install.

0.2.1 (10-19-2020)
==================

Notes
-----
* Formatted readme.

0.2 (10-19-2020)
================

Bugs
----
* Fixed an upgrading issue: when upgrading ``quesadiya``, ``admin.db`` was removed as well.
  In the new version, ``admin.db`` and project folder are created after installing a package.

Notes
-----
* Beta release.

0.1 (10-19-2020)
================

Notes
-----
* Initial release (beta).
